@@ -19,6 +19,7 @@ import xml.etree.ElementTree as ET
 import subprocess
 import sys
 
+import database
 import util
 import monitor
 import wls
@@ -30,31 +31,32 @@ logging.basicConfig(level=logging.INFO)
 def get_xml_namespace(re):
 	return ''.join(re.tag.split("}")[:-1])+'}'
 
-def saveDomain(domainName,domainhome,version,adminurl,user,pwd):
+def saveDomain(machine,domainName,domainhome,version,adminurl,user,pwd):
 	
-	_data = [None,[domainName,domainhome,version,adminurl,user,pwd],None]
-	util.saveDB(domain=True,data=_data)
+	_data = [None,None,[domainName,domainhome,version,adminurl,user,pwd],None]
+	database.saveDB(machine,domain=True,data=_data)
 
-def saveServer(name,host,port,type,domain):
-	_data = [None,None,[name,host,port,type,domain]]
-	util.saveDB(server=True,data=_data)
+def saveServer(machine,name,host,port,type,domain):
+	_data = [None,None,None,[name,host,port,type,domain]]
+	database.saveDB(machine,server=True,data=_data)
 
-def saveWLS(wlsHome,version,nmPort):
-	_data = [[wlsHome,version,nmPort],None,None]
-	util.saveDB(wlss=True,data=_data)
+def saveWLS(machine,wlsHome,version,nmPort):
+	_data = [None,[wlsHome,version,nmPort],None,None]
+	database.saveDB(machine,wlss=True,data=_data)
 
+def saveMachine(machine,port):
+	_data = [port,None,None,None]
+	database.saveDB(machine,mac=True,data=_data)
 
 def searchAll():
-	print "Searching weblogic and domains on this machine ,please wait ."
-	print ""
-	if os.path.isfile(util.wlnm_data_file):
-		os.remove(util.wlnm_data_file)
-	searchwls()
-	searchDomain()
-	showAll()
-
-def searchwls():
+	#print "Searching weblogic and domains on this machine ,please wait ."
+	#print ""
+	
 	version='0.0'
+	wlsresult = []
+	serverresult = []
+	domainresult = []
+
 	for curdir, dirs, files in os.walk('/'):
 	     if  'weblogic.jar' in files and os.path.basename(curdir) == 'lib' and os.path.basename(os.path.dirname(curdir)) == 'server':
 		process = subprocess.Popen("unzip -p %s/weblogic.jar META-INF/MANIFEST.MF" % os.path.abspath(curdir),shell=True, stdout=subprocess.PIPE)
@@ -72,48 +74,12 @@ def searchwls():
 		if not nmPort:
 			nmPort ='NA'
 
-		saveWLS(wls_home , version , nmPort)
+		wlsresult.append((wls_home , version , nmPort))
+		#saveWLS(wls_home , version , nmPort)
 
 	
-def getwlsHome(version):
 
-	wlsDB,wls = util.loadDB(wlss=True)[0]
-
-	for w in wls:
-	    if version == wlsDB[w]["version"]:
-		return wlsDB[w]["home"]
-	return
-
-def getwls(name):
-	#logging.debug ("name is %s" % name)
-	[wlsDB,wls],[domainsDB,domains],[serversDB,servers] = util.loadDB(wlss=True,domain=True,server=True)
-	version = ''
-	domain = ''
-	wlsHome = ''
-	adminurl =''
-	user = ''
-	pwd = ''
-	for server in servers:
-		if name == serversDB[server]["name"] :
-			domain = serversDB[server]["domain"]
-	if domain :
-		for idomain in domains:
-			if domain == idomain :
-				version = domainsDB[idomain]["version"]
-				adminurl = domainsDB[idomain]["adminurl"]
-				user = domainsDB[idomain]["user"]
-				pwd = domainsDB[idomain]["pwd"]
-	else:
-		#print "could not find such server in local db , make sure you spell correct"
-		return ('','','','')
-
-	for key in wls:
-		if version == wlsDB[key]["version"]:
-			wlsHome = wlsDB[key]["home"]
-
-	return (adminurl,wlsHome,user,pwd)	
-
-def searchDomain():
+	
 	for curdir, dirs, files in os.walk('/'):
 	     if  'config.xml' in files and os.path.basename(curdir) == 'config' :
 		  #print "domain name :%s" % os.path.basename(os.path.dirname(curdir))
@@ -148,49 +114,153 @@ def searchDomain():
 			adminPort = _port if _name == adminserver else adminPort
 			adminHost = _host if _name == adminserver else adminHost
 			#logging.debug (_name,_host,_port,_type,domainname)
-			saveServer(_name,_host,_port,_type,domainname)
+			serverresult.append((_name,_host,_port,_type,domainname))
+			#saveServer(_name,_host,_port,_type,domainname)
 
 		  adminurl = "t3://%s:%s" % (adminHost,adminPort)
-
-		  wlsHome = getwlsHome(domainversion)
+		
+		  #wlsHome = getwlsHome(domainversion)
+		  for wlsinst in wlsresult :
+			if domainversion == wlsinst[1]:
+				wlsHome = wlsinst[0]
 		  pwd = wls.getAdminPass(homedir,enPass,wlsHome)
-		  saveDomain(domainname,homedir,domainversion,adminurl,user,pwd)
+		  
+		  domainresult.append((domainname,homedir,domainversion,adminurl,user,pwd))
+
+		  #saveDomain(domainname,homedir,domainversion,adminurl,user,pwd)
 
 
-	print ""
-	print "Search completed!"
-	print ""
+	#print ""
+	#print "Search completed!"
+	#print ""
+	return wlsresult,serverresult,domainresult
+
+def searchNM(wlsHome):
+	port = ""
+	with open('%s/common/nodemanager/nodemanager.properties' % wlsHome) as f:
+		lines = f.read().splitlines()
+		for line in lines:
+			if "ListenPort" == line.split("=")[0]:
+				port = line.split("=")[-1]
+	f.close()
+	return port			
+
+def getMachineAgentPort(machine):
+	macDB,mac = database.loadAllDB()
+
+	for m in mac :
+		if machine == m :
+			return macDB[m]["agentport"]
+
+	return
 	
 
-def show(args = []):
+def getwlsHome(machine,version):
+
+	wlsDB,wls = database.loadDB(machine,wlss=True)[0]
+
+	for w in wls:
+	    if version == wlsDB[w]["version"]:
+		return wlsDB[w]["home"]
+	return
+
+def getwlsHomeByNmport(machine,port):
+	
+	wlsDB,wls = database.loadDB(machine,wlss=True)[0]
+	wls_home = ''
+	for w in wls:
+	    if port == wlsDB[w]["nmport"]:
+		wls_home = wlsDB[w]["home"]    
+
+	if wls_home :
+		return wls_home
+	else:
+		raise Exception("%s is not valid nodemanager port !" % port)
+
+def getwls(machine,name):
+	#logging.debug ("name is %s" % name)
+	[wlsDB,wls],[domainsDB,domains],[serversDB,servers] = database.loadDB(machine,wlss=True,domain=True,server=True)
+	version = ''
+	domain = ''
+	wlsHome = ''
+	adminurl =''
+	user = ''
+	pwd = ''
+	for server in servers:
+		if name == serversDB[server]["name"] :
+			domain = serversDB[server]["domain"]
+	if domain :
+		for idomain in domains:
+			if domain == idomain :
+				version = domainsDB[idomain]["version"]
+				adminurl = domainsDB[idomain]["adminurl"]
+				user = domainsDB[idomain]["user"]
+				pwd = domainsDB[idomain]["pwd"]
+	else:
+		#print "could not find such server in local db , make sure you spell correct"
+		return ('','','','')
+
+	for key in wls:
+		if version == wlsDB[key]["version"]:
+			wlsHome = wlsDB[key]["home"]
+
+	return (adminurl,wlsHome,user,pwd)	
+
+def getDomainHome(machine,domainName):
+	
+
+	domainsDB,domains = database.loadDB(machine,domain=True)[1]
+	if domainName in domains:
+		return domainsDB[domainName]['home']
+	else:
+		return
+
+def isWlsPort(machine,port):
+	iswls = False
+	[wlsDB,wls],[serversDB,servers] = database.loadDB(machine,wlss=True,server=True)[0::2]
+	#print [wlsDB,wls],[serversDB,servers] 
+	wls_home = ''
+
+	for w in wls:
+	    if port == wlsDB[w]["nmport"]:
+		iswls = True    
+	
+
+	for server in servers:
+		if port == serversDB[server]["port"] :
+			iswls = True
+	
+	return iswls
+
+def show(machine,args = []):
 	if not args :
-		showAll()
+		showAll(machine)
 	else:
 		print ""
-		showServers(args)
+		showServers(machine,args)
 
-def showAll():
-	domainsDB,domains = util.loadDB(domain=True)[1]
+def showAll(machine):
+	domainsDB,domains = database.loadDB(machine,domain=True)[1]
 	print ""
 	for domain in domains:
-	    showServers([domain])
+	    showServers(machine,[domain])
 
 	
 
-def showDomains():
+def showDomains(machine):
 	
 	table = [["Name", "Version", "HomeDirectory","AdminURL"]]
 	
-	domainsDB,domains = util.loadDB(domain=True)[1]
+	domainsDB,domains = database.loadDB(machine,domain=True)[1]
 	for domain in domains:
 	    table.append([domain,domainsDB[domain]["version"],domainsDB[domain]["home"],domainsDB[domain]["adminurl"]])
 	    
 	util.pprint_table(table)
 
 
-def showServers(domain):
+def showServers(machine,domain):
 	
-	serversDB,servers = util.loadDB(server=True)[2]
+	serversDB,servers = database.loadDB(machine,server=True)[2]
 
 	for _domain in domain:
 		print "[[%s]]" % _domain
@@ -204,11 +274,11 @@ def showServers(domain):
 	
 	
 
-def showWLS():
+def showWLS(machine):
 	table = [["Name", "Version", "HomeDirectory" , "NM Port","NM Status"]]
 	
 	
-	wlsDB,wls = util.loadDB(wlss=True)[0]
+	wlsDB,wls = database.loadDB(machine,wlss=True)[0]
 
 	_status = 'DOWN'
 
@@ -219,23 +289,24 @@ def showWLS():
 	    
 	util.pprint_table(table)
 
-def getDomain(domainName):
-	domainsDB,domains = util.loadDB(domain=True)[1]
-	if domainName in domainsDB.keys():
-		return domainsDB[domainName]
-	else:
-		return
 
-def searchNM(wlsHome):
-	port = ""
-	with open('%s/common/nodemanager/nodemanager.properties' % wlsHome) as f:
-		lines = f.read().splitlines()
-		for line in lines:
-			if "ListenPort" == line.split("=")[0]:
-				port = line.split("=")[-1]
-	f.close()
-	return port			
+def showMachines():
+	table = [["Machine Name", "agent port", "agent status" ]]
 
+	macDB,mac = database.loadAllDB()
+	_status = 'DOWN'
+
+	for m in mac:
+		if util.checkport(macDB[m]["agentport"]):
+			_status = 'UP'
+		table.append([m,macDB[m]["agentport"], _status])
+	util.pprint_table(table)
+
+
+
+
+
+'''
 
 def checkinit(daemon):
     if not os.path.isfile(util.wlnm_data_file):
@@ -252,6 +323,7 @@ def checkinit(daemon):
 			util.initDB()
 			print 'Weblogic node master run as client mode ,use connect command to connect target machine.'
 			print ""	
+'''
 
 #print searchNM("/bea/1035/wlserver_10.3")
 #searchwls()
